{ config, pkgs, lib, agenix, ... }:

{

    imports = [

		agenix.nixosModule

		../../modules

		# Reverse proxy
		./nginx.nix

		# Website
		./website.nix

    ];

	networking.hostName = "sif";

	boot.loader = {
		grub.enable = false;
		generic-extlinux-compatible.enable = true;
	};

	documentation.enable = false;

	environment.systemPackages = with pkgs; [
		git
		vim
	];

    age.secrets."website-secret".file = ../../secrets/website.age;

	system.stateVersion = "21.11";

	riley = {
		gui = false;
		kak = {
			enable = true;
			nix = true;
		};
	};

	users.users."riley" = {
		isNormalUser = true;
		extraGroups = [ "wheel" ];
	};

	networking.interfaces.eth0.useDHCP = true;

	boot.kernelPackages = pkgs.linuxPackages_latest;

	fileSystems."/" = {
		device = "/dev/disk/by-label/NIXOS_SD";
		fsType = "ext4";
	};

	nix = {
		distributedBuilds = true;
		buildMachines = [{
			hostName = "thor";
			systems = [
    			"x86_64-linux"
                "aarch64-linux"
			];
            supportedFeatures = [
                "nixos-test"
                "benchmark"
                "big-parallel"
                "kvm"
            ];
		}];
	};

	programs.ssh.extraConfig = ''
        Host thor
            HostName thor
            Port 22
            User riley
            IdentitiesOnly yes
            IdentityFile /root/.ssh/id_ed25519
    '';

}
